#ifndef NT2_INCLUDE_FUNCTIONS_FIRSTBITSET_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FIRSTBITSET_HPP_INCLUDED

#include <nt2/bitwise/include/functions/firstbitset.hpp>

#endif
